from pathlib import Path

from textual.widgets import Tree
from textual.widgets.tree import TreeNode

class DirectoryGenerator:
    def __init__(self, tree: Tree):
        self.tree = tree
        self.root_path = Path(str(self.tree.root.label))
        self.paths_list = []
        self.generation_status = bool
        self.generation_status_error = ""
        self.extract_paths(tree.root, [])
        self.generate_dirs(self.paths_list)

    def extract_paths(self, node: TreeNode, current_path: [str]):
        new_path = current_path + [str(node.label)]
        if node.children:
            for child_dir in node.children:
                self.extract_paths(child_dir, new_path)
        else:
            self.paths_list.append(Path(*new_path))

    def generate_dirs(self, paths_list: []):
        if self.root_path.is_dir():
            for path in paths_list:
                try:
                    path.mkdir(parents=True, exist_ok=True)
                    self.generation_status = True
                except Exception as e:
                    self.generation_status_error = f"Error creating directory {path}: {e}"
                    self.generation_status = False
        else:
            self.generation_status_error = "The root node of the tree should be an existing directory"
            self.generation_status = False

