from pathlib import Path

from textual import events
from textual.app import ComposeResult
from textual.screen import ModalScreen
from textual.validation import Validator, ValidationResult
from textual.widgets import Input, RichLog


class PathValidator(Validator):
    """Checks whether the path from Input widget exists"""

    def validate(self, value: str) -> ValidationResult:
        path = Path(value)
        if path.exists() and value != "":
            return self.success()
        return self.failure("Invalid Path!")


class NewRootScreen(ModalScreen[str]):
    """Screen for changing the current root node label"""

    def compose(self) -> ComposeResult:
        yield Input(
            validators=[PathValidator()],
            validate_on=["submitted"],
            placeholder="input a path",
            id="new_root_input",
            type="text",
        )
        yield RichLog(id="error_log", markup=True, max_lines=1, auto_scroll=False)

    def on_key(self, event: events.Key) -> None:
        """Closes the Load screen"""
        if event.key == "escape":
            self.app.pop_screen()

    def on_input_submitted(self, event: Input.Submitted):
        if event.validation_result.is_valid:
            self.dismiss(event.value)
        else:
            text_log = self.query_one(RichLog)
            text_log.write("[bold magenta]Invalid Path!")

    def on_input_changed(self, event: Input.Changed):
        text_log = self.query_one(RichLog)
        text_log.clear()
